==> syncope-2.0.10-source-release.zip: syncope-2.0.10/core/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/validation/entity/SchedTaskValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa.validation.entity;

import java.text.ParseException;

import javax.validation.ConstraintValidatorContext;
import org.apache.commons.lang3.ClassUtils;
import org.apache.syncope.common.lib.types.EntityViolationType;
import org.apache.syncope.core.persistence.api.entity.task.ProvisioningTask;
import org.apache.syncope.core.persistence.api.entity.task.SchedTask;
import org.apache.syncope.core.provisioning.api.job.SchedTaskJobDelegate;
import org.quartz.CronExpression;

public class SchedTaskValidator extends AbstractValidator<SchedTaskCheck, SchedTask> {

    @Override
    public boolean isValid(final SchedTask task, final ConstraintValidatorContext context) {
        boolean isValid = true;

        if (!(task instanceof ProvisioningTask)) {
            Class<?> jobDelegateClass = null;
            try {
                jobDelegateClass = ClassUtils.getClass(task.getJobDelegateClassName());
                isValid = SchedTaskJobDelegate.class.isAssignableFrom(jobDelegateClass);
            } catch (Exception e) {
                LOG.error("Invalid JobDelegate class specified", e);
                isValid = false;
            }
            if (jobDelegateClass == null || !isValid) {
                isValid = false;

                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(
                        getTemplate(EntityViolationType.InvalidSchedTask, "Invalid job delegate class name")).
                        addPropertyNode("jobDelegateClassName").addConstraintViolation();
            }
        }

        if (isValid && task.getCronExpression() != null) {
            try {
                new CronExpression(task.getCronExpression());
            } catch (ParseException e) {
                LOG.error("Invalid cron expression '" + task.getCronExpression() + "'", e);
                isValid = false;

                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(
                        getTemplate(EntityViolationType.InvalidSchedTask, "Invalid cron expression")).
                        addPropertyNode("cronExpression").addConstraintViolation();
            }
        }

        return isValid;
    }
}

==> syncope-2.1.11-source-release.zip: syncope-2.1.11/core/persistence-jpa/src/main/java/org/apache/syncope/core/persistence/jpa/validation/entity/SchedTaskValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa.validation.entity;

import java.text.ParseException;

import javax.validation.ConstraintValidatorContext;
import org.apache.syncope.common.lib.types.EntityViolationType;
import org.apache.syncope.core.persistence.api.entity.task.SchedTask;
import org.quartz.CronExpression;

public class SchedTaskValidator extends AbstractValidator<SchedTaskCheck, SchedTask> {

    @Override
    public boolean isValid(final SchedTask task, final ConstraintValidatorContext context) {
        boolean isValid = true;
        if (task.getCronExpression() != null) {
            try {
                new CronExpression(task.getCronExpression());
            } catch (ParseException e) {
                LOG.error("Invalid cron expression '" + task.getCronExpression() + "'", e);
                isValid = false;

                context.disableDefaultConstraintViolation();
                context.buildConstraintViolationWithTemplate(
                        getTemplate(EntityViolationType.InvalidSchedTask, "Invalid cron expression")).
                        addPropertyNode("cronExpression").addConstraintViolation();
            }
        }

        return isValid;
    }
}
